This function updates some of the quantities in the HDRDA classifier based on
updated values of lambda and gamma. The update can greatly
expedite cross-validation to examine a large grid of values for lambda
and gamma.
update_hdrda(obj, lambda = 1, gamma = 0)a hdrda object
a numeric value between 0 and 1, inclusively
a numeric value (nonnegative)
a hdrda object with updated estimates